#!/usr/bin/perl -w

use HTML::Parser;

###############################################################
# HTML-i teisendamisega tegelev osa
###############################################################

my $p = HTML::Parser->new(api_version => 3);
$p->handler(text => \ &textHandler, "self, text");
$p->handler(start => \ &startHandler,"self, tagname, attr, attrseq, text");
$p->handler(end => \ &endHandler,"self, tagname, text");
$p->handler(default => "");
$p->unbroken_text(1);


my $lipp = 1;
my $fontsize = 0;
my $paragraphnr = 0;
my $emptyparagraph = 1;
my $bold = 0;
my $italic = 0;
my $heading = 0;
my $intable = 0;
my $unimportant = 0;
my $captiontext="";
my $caption = 0;

sub textHandler{
  my($self, $otext) = @_;
  $otext =~ tr/\t/ /;
  $otext =~ tr/\n/ /;
  $otext =~ tr/\0-\37//d;
  $otext =~ tr/\x7f//d;
  $otext =~ tr/\x85/.../;
  $otext =~ tr/\x86-\x87/*/;
  $otext =~ tr/\x8B/`/;             
  $otext =~ s/\x8F/&cedil;/g;
  $otext =~ tr/\x91-\x92/'/;
  $otext =~ tr/\x93-\x94/"/;
  $otext =~ tr//"/;
  $otext =~ tr//"/;
  $otext =~ tr/\x95/x2a/; # bullet -> asterisk
  $otext =~ tr/\x96-\x97/-/;
  $otext =~ s/\x99/TM/g;
  $otext =~ tr/\x9B/'/;
  $otext =~ tr/\x9E/*/;
  $otext =~ s:&nbsp;: :g; 
  $otext =~ s/\n/ /g;
  $otext =~ s/\r//g;
  $otext =~ s/\s+/ /g;
  $otext =~ s/^\s+//g ;
  $otext =~ s/&\#8220;/\xAB/g;
  $otext =~ s/&\#8221;/\xBB/g;
  if ($otext ne "" ) {
    $emptyparagraph = 0 ;
    print "<hi rend='bold'>" if ($bold && ! $heading);
    print "<hi rend='italic'>" if ($italic); 
  }
  $captiontext.= $otext if ($caption);
  print "$otext " if ($lipp && !$unimportant);   #thik peab olema lpus,
                                #sest vahel pannakse kaks teksti tkki jrjest
  print "</hi>" if ($italic && $otext ne "");
  print "</hi>" if ($bold && $otext ne "" && !$heading);
  
}

sub startHandler{
  my($self, $tagname, $attr, $attrseq, $otext) = @_;
  $lipp = 0 if ($tagname eq "head");
  if ($tagname eq "p" || $tagname eq "br" || $tagname eq "p/"){
    if (!$emptyparagraph){
      $paragraphnr++;
      print "</p>\n";# if ($paragraphnr > 1);
      # print "<p nr=$paragraphnr>";
      print ("\n") if ($paragraphnr < 2);
      print "<p>";
    }
    $emptyparagraph = 1;
  }
  if ($tagname eq "tr"){
    $intable = 1;
  } 
  if ($tagname eq "table"){
    #print "<p>";
  }
  if ($tagname eq "td"){
    if (exists $attr->{class}){
       if ($attr->{class} eq "Text10px"){ #Postimehe pildiallkiri
         $caption=1;
         $captiontext="Pildi allkiri: ";
         $unimportant =1; 
       }
       if ($attr->{class} =~ /text11/){ #Pevalehe mitteoluline
         $unimportant =1; 
       }
       if ($attr->{class} eq "redtext"){ #Pevalehe pildiallkiri
         $caption=1;
         $captiontext="Pildi allkiri: ";
         $unimportant =1; 
       }
       if ($attr->{class} eq "kuumpealkiri"){ #Pevalehe pealkiri
        print "\n<div0 type='unknown'><head>";
        $paragraphnr = 0;
        $heading = 1;
       }
    }
    if (exists $attr->{align}){
       if ($attr->{align} eq "right"){
         $unimportant=1;
       }
    }
  } 
  if ($tagname eq "font"){
    if (exists $attr->{class}){
        if ($attr->{class} eq "articleTitle") {
          print "\n<div0 type='unknown'><head>";
          $paragraphnr = 0;
          $heading = 1;
        }
        if ($attr->{class} eq "articleHeadSource" || $attr->{class} eq "sourceDate" || $attr->{class} eq "smallBody") {
           $caption=1;
           $captiontext="Pildi allkiri: ";
           $unimportant = 1;
        }
        if ($attr->{class} eq "imageSrcCapS" || $attr->{class} eq "imgSrcCaptionSmall" || $attr->{class} eq "imageCaptionSmall") {
           $unimportant = 1;
        }
        if ($attr->{class} =~ m/related/){
           $unimportant = 1;
        }
 
    }
  }
  if ($tagname eq "b"){
    $bold = 1;
  }
  if ($tagname eq "i"){
    $italic = 1;
  }
  if ($tagname =~ m/h[1|2|3]+/){
   print "\n<div1 type='unknown'><head>";
      $paragraphnr = 0;
      $heading = 1;
  }
  if ($tagname eq "span") {
    if (exists $attr->{class}){
      if ($attr->{class} =~ m/TextTitle/){                 #postimehe pealkiri
        print "\n<div0 type='unknown'><head>";
        $paragraphnr = 0;
        $heading = 1;
      }       
      if ($attr->{class} =~ m/TextDateSmall/){
        $unimportant=1;
      } 
      if ($attr->{class} =~ m/TextDarkBlue/){
        $unimportant=1;
      } 
      if ($attr->{class} =~ m/text12b/){
        $bold = 1;
      } 
    }
  }
  if ($tagname eq "script"|| $tagname eq "code") {
    $unimportant = 1;
  }
  
}

sub endHandler{
  my($self, $tagname, $otext) = @_;
  $lipp = 1 if ($tagname eq "head");
  if ($tagname eq "font"){
     if ($caption){
       $caption=0;
       $unimportant=0;
     }
     $unimportant=0;
     if ($heading){
       print "</head>\n";
       $heading = 0;  
     }   

  }
  if ($tagname eq "b") {
     $bold = 0;
  }
  if ($tagname eq "i") {
     $italic = 0;
  } 
  if ($tagname eq "tr") {
       print "</p>\n<p>";
  } 
  if ($tagname eq "table"){
     print "</p>\n<p>";
  }
  if ($tagname eq "td"){
     if ($caption){
       $caption=0;
       $unimportant=0;
     }
     $unimportant=0;
     if ($heading){
       print "</head>\n";
       $heading = 0;  
     }   
  }
  if ($tagname =~ m/h[1|2|3]+/){
      print "</head>\n";
      $heading = 0;
  }
  if ($tagname eq "span"){
     if ($heading) {
       print "</head>\n";
       $heading = 0;  
     }
     if ($unimportant) {
       $unimportant=0;   
     }
     if ($bold) {
       $bold = 0;
     }
  } 
  if ($tagname eq "body") {
     if ($captiontext ne ""){
       print "\n<p>", $captiontext, " </p>\n";
     }
  }   
  if ($tagname eq "script" || $tagname eq "code") {
    $unimportant = 0;
  }

}


##################################################################
# main
##################################################################
$p->parse_file(shift || die) || die $!;


 
